.. BadWing documentation master file, created by
   sphinx-quickstart on Tue Mar 31 16:22:18 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

BadWing |:butterfly:|
=====================

Skateboarder/Platformer/Lepidopterist Game using Arcade & Pymunk

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage/installation
   usage/quickstart
   usage/cli
   reference/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
